@@ -1,6 +1,5 @@
 package Lingua::LO::Romanize::Word;
 
-use warnings;
 use strict;
 use utf8;
 
@@ -16,11 +15,11 @@ Lingua::LO::Romanize::Word - Class for words, used by Lingua::LO::Romanize.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 has 'word_str' => (
     is          => 'ro',
@@ -232,10 +231,6 @@ Please report any bugs or feature requests to C<bug-lingua-lo-romanize at rt.cpa
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Lingua-LO-Romanize>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-=head1 UTF-8 FLAG
-
-This treats utf8 flag transparently.
-
 =head1 SEE ALSO
 
 L<Lingua::LO::Romanize>
